#
# spec file for package ghc-zip-archive
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name zip-archive
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.3
Release:        1.3
Summary:        Library for creating and modifying zip archives
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-digest-devel
BuildRequires:  ghc-digest-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-pretty-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unix-prof
BuildRequires:  ghc-zlib-devel
BuildRequires:  ghc-zlib-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
%endif

%description
The zip-archive library provides functions for creating, modifying, and
extracting files from zip archives. The zip archive format is documented in
<http://www.pkware.com/documents/casestudies/APPNOTE.TXT>.

Certain simplifying assumptions are made about the zip archives: in particular,
there is no support for strong encryption, zip files that span multiple disks,
ZIP64, OS-specific file attributes, or compression methods other than Deflate.
However, the library should be able to read the most common zip archives, and
the archives it produces should be readable by all standard unzip programs.

Archives are built and extracted in memory, so manipulating large zip files
will consume a lot of memory. If you work with large zip files or need features
not supported by this library, a better choice may be
<http://hackage.haskell.org/package/zip zip>, which uses a memory-efficient
streaming approach. However, zip can only read and write archives inside
instances of MonadIO, so zip-archive is a better choice if you want to
manipulate zip archives in "pure" contexts.

As an example of the use of the library, a standalone zip archiver and
extracter is provided in the source distribution.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.markdown changelog

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Mar  4 2023 Peter Simons <psimons@suse.com>
- Update zip-archive to version 0.4.3.
  zip-archive 0.4.3
  * Improve code for retrieving compressed data of unknown length (#63).
    Do not assume we'll have the signature 0x08074b50 that is
    sometimes used for the data description, because it is not
    in the spec and is not always used.
  * Make some record fields strict.
  * Require binary >= 0.7.2, remove some CPP
* Mon Sep 26 2022 Peter Simons <psimons@suse.com>
- Update zip-archive to version 0.4.2.2.
  zip-archive 0.4.2.2
  * Use `command -v` before trying `which` in the test suite (#62).
    `command` is a bash builtin, but for busybox we'll need `which`.
* Thu Mar  3 2022 Peter Simons <psimons@suse.com>
- Update zip-archive to version 0.4.2.1.
  zip-archive 0.4.2.1
  * Fix Windows build regression (#61).
  zip-archive 0.4.2
  * Fix problem with files with colon (#89).
  * Remove build-tools.  This was used to indicate that the 'unzip'
    executable was needed for testing, but it was never intended to be used
    this way and now the field is deprecated.  The current test suite
    simply skips the test using the unzip executable (with a warning) if
    'unzip' is not in the path.
  * Remove existing symlinks when extracting zip files with symlinks (#60,
    Vikrem).  Previously, writeEntry would raise an error if it tried to
    create a symlink and a symlink already existed at that path.  This
    behavior was inconsistent with its behavior for regular files, which
    it overwrote without comment.  This commit causes symlinks to be replaced
    by writeEntry instead of an error being raised.
  * Remove binary < 0.6 CPP.  It's no longer needed because we don't support
    binary < 0.6.  Also use manySig instead of many, to get better error
    messages.
  * Add type annotation for printf.
  * Better checking for unsafe paths (#55).  This method allows things like
    `foo/bar/../../baz`.
  * Require base >= 4.5 (#56)
  * Add GitHub CI.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update zip-archive to version 0.4.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Apr 24 2019 psimons@suse.com
- Update zip-archive to version 0.4.1.
  zip-archive 0.4.1
  * writEntry behavior change: Improve raising of UnsafePath error (#55).
    Previously we raised this error spuriously when archives were unpacked
    outside the working directory.  Now we raise it if eRelativePath contains
    ".." as a path component, or eRelativePath path is an absolute path and
    there is no separate destination directory.  (Note that `/foo/bar` is fine
    as a path as long as a destination directory, e.g. `/usr/local`, is
    specified.)
* Tue Dec  4 2018 psimons@suse.com
- Update zip-archive to version 0.4.
  zip-archive 0.4
  * Implement read-only support for PKWARE encryption (Sergii Rudchenko).
    The "traditional" PKWARE encryption is a symmetric encryption
    algorithm described in zip format specification in section 6.1.
    This change allows to extract basic "password-protected" entries from
    ZIP files.  Note that the standard file extraction function
    extractFilesFromArchive does not decrypt entries (it will raise
    an exception if it encounters an encrypted entry). To handle
    archives with encrypted entries, use the new function
    fromEncryptedEntry.
    API changes:
    + Add eEncryptionMethod field to Entry.
    + Add EncryptionMethod type.
    + Add function isEncryptedEntry.
    + Add function fromEncryptedEntry.
  * Add CannotWriteEncryptedEntry constructor to ZipException.
  * Add UnsafePath to ZipException (#50).
  * writeEntry: raise UnsafePath exception for unsafe paths (#50).
    This prevents malicious zip files from overwriting paths
    above the working directory.
  * Add Paths_zip_archive to autogen-modules.
  * Clarify README and cabal description.
  * Specify cabal-version: 2.0.  Otherwise we get an unknown build
    tool error using `build-depends` without a custom Setup.hs.
  * Change build-type to simple.  Retain 'build-tools: unzip' in
    test stanza, though now it doesn't do anything except give a
    hint to external tools.  If unzip is not found in the path,
    the test suite prints a message and counts the test that
    requires unzip as succeeding (see #51).
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update zip-archive to version 0.3.3.
  zip-archive 0.3.3
  * Remove dependency on old-time (typedrat).
  * Drop splitBase flag and support for base versions < 3.
  zip-archive 0.3.2.5
  * Move 'build-tools: unzip' from library stanza to test stanza.
    unzip should only be required for testing, not for regular
    builds of the library.
* Mon May 14 2018 psimons@suse.com
- Update zip-archive to version 0.3.2.4.
  * Use createSymbolicLink instead of createFileLink in tests. This allows
    us to lower the directory lower bound (#40).
  * Fixes for handling of symbolic links (#39, Tommaso Piazza).
  * Fixes for symbolic link tests, and additional tests.
  * Add ZipOption to preserve symbolic links (#37, Tommaso Piazza).
    Add OptPreserveSymbolicLinks constructor to ZipOption.  If this option
    is set, symbolic links will be preserved.  Symbolic links are not
    supported on Windows.
  * Require binary >= 0.6 (#36).
  * Improve exit handling in zip-archive program.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 0.3.1.1.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 0.3.1.
* Wed May  3 2017 psimons@suse.com
- Update to version 0.3.0.6 with cabal2obs.
* Mon Jan 23 2017 psimons@suse.com
- Update to version 0.3.0.5 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.3.0.5 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.3.7 revision 0 with cabal2obs.
* Sun Feb  1 2015 mpluskal@suse.com
- Update to 0.2.3.7:
  * Declared test suite's dependency on 'zip' using custom Setup.lhs (#21,#22).
  * Removed hard-coded path to zip in test suite (#21).
  * Removed misplaced build-depends in cabal file.
  * Allow compilation with binary >= 0.5.  Note that toArchiveOrFail
    is not safe when compiled against binary < 0.7; it will never
    return a Left value, and will raise an error if parsing fails,
    just like toArchive.  This is documented in the haddocks.
    This is ugly, but justified by the need to have a version
    of zip-archive that compiles against older versions of binary.
  * Make sure all path comparisons compare normalized paths.
    So, findEntryByPath "foo" will find something stored as "./foo"
    in the zip container.
  * Better normalization of file paths:  "./foo/bar" and "foo/./bar"
    are now treated the same, for example.  Note that we do not
    yet treat "foo/../bar" and "bar" as the same.
  * Removed lower bound on directory (>= 1.2), which caused build
    failures with GHC 7.4 and 7.6.
  * Added travis script for automatic testing on 3 GHC versions.
  * Require binary >= 0.7 and directory >= 1.2.  The newer binary
    is needed to provide toArchiveOrFail.  The other change is
    mainly for convenience, to avoid lots of ugly conditional
    compilation.
  * Export new function `toArchiveOrFail`.  Closes #17.
  * Set general purpose bit flag to use UTF8 in local file header.
    Otherwise we get a mismatch between the flag in the central
    directory and the flag in the local file header, which causes some
    programs not to be able to extract the files.  Closes #19.
  * Fix a stack overflow in getWordsTillSig (Tristan Ravitch).
    recognize UTF-8 encoded file names (Tobias Brandt).
  * Added OptLocation, to specify the path to which a file
    is to be added when readEntry is used (Stephen McIntosh).
* Thu Mar 13 2014 sbahling@suse.com
- Add missing %%defattr
* Tue Dec 31 2013 peter.trommler@ohm-hochschule.de
- update to 0.2 from upstream
  * replace dependency on utf8-string by text
* Wed May 15 2013 peter.trommler@ohm-hochschule.de
- new spec file template generated by cabal-rpm
* Mon Mar 11 2013 peter.trommler@ohm-hochschule.de
- update to 0.1.3.4 from upstream
  * use new binary API
  * use new directory API
  * general code cleanup
  * added testsuite
- requirement for pandoc 1.11
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.1.1.8 from upstream
  * fix parsing of "version needed to extract" field
  * license now BSD-3-Clause
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 spec file template
* Wed Jan 18 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
